@@ -94,7 +94,7 @@ class monitoring2:
 	add_capability_to_org(org_id, capability) - Добавление эксклюзивного права организации по id
 	'''
 
-	def __init__(self, login, password, url = 'http://taxplayer.ensyco.local', crpt = False, echo = True):
+	def __init__(self, login, password, url = 'http://prod-mon.ofd.nov', crpt = False, echo = True):
 		self.URL = url
 		self.mon_login = login
 		self.__mon_password = password
